Enum lychee_lib::Base
source · [−]Expand description
When encountering links without a full domain in a document, the base determines where this resource can be found. Both, local and remote targets are supported.
Variants
Local(PathBuf)
Local file path pointing to root directory
Remote(Url)
Remote URL pointing to a website homepage