Remap rules which allow to map URLs matching a pattern to a different URL.
Notes
Use in moderation as there are no sanity or performance guarantees.
- There is no constraint on remap rules upon instantiation or during remapping. In particular, rules are checked sequentially so later rules might contradict with earlier ones if they both match a URL.
- A large rule set has a performance impact because the client needs to match every link against all rules.