pub struct Hint(/* private fields */);Expand description
An informative and friendly message created during the invocation of the program to be displayed before termination, to improve user experience.