Struct lychee_lib::Request
source · [−]pub struct Request {
pub uri: Uri,
pub source: InputSource,
pub element: Option<String>,
pub attribute: Option<String>,
}Expand description
A request type that can be handle by lychee
Fields
uri: UriA valid Uniform Resource Identifier of a given endpoint, which can be checked with lychee
source: InputSourceThe resource which contained the given URI
element: Option<String>Specifies how the URI was rendered inside a document
(for example img, a, pre, or code).
In case of plaintext input the field is None.
attribute: Option<String>Specifies the attribute (e.g. href) that contained the URI
Implementations