pub struct WaitGroup { /* private fields */ }Expand description
Manager for a particular wait group. This can spawn a number of WaitGuards
and it can then wait for them to all complete.
Each WaitGroup is single-use—calling WaitGroup::wait to start
waiting consumes the WaitGroup. Additionally, once all WaitGuards
have been dropped, it is not possible to create any more WaitGuards.
Implementations